---
title: <span class="badge object-type-enum"></span> QueryEditorExpressionType
---
# <span class="badge object-type-enum"></span> QueryEditorExpressionType

## Definition

```python
class QueryEditorExpressionType(enum.StrEnum):
    PROPERTY = "property"
    OPERATOR = "operator"
    OR = "or"
    AND = "and"
    GROUP_BY = "groupBy"
    FUNCTION = "function"
    FUNCTION_PARAMETER = "functionParameter"
```
